@@ -13,7 +13,7 @@ use IO::Capture::Stderr;
 use YAML qw(LoadFile);
 
 use vars qw($VERSION);
-$VERSION=0.71;
+$VERSION=0.72;
 
 use Module::Pluggable search_path=>['Module::CPANTS::Kwalitee'];
 
@@ -61,6 +61,10 @@ sub unpack {
         $me->d->{extractable}=0;
         $me->d->{cpants_errors}=$error;
         $me->d->{kwalitee}{extractable}=0;
+        my ($vol,$dir,$name)=splitpath($me->dist);
+        $name=~s/\..*$//;
+        $name=~s/\-[\d\.]+$//;
+        $me->d->{dist}=$name;
         return $error;
     }
     
