@@ -2,9 +2,6 @@ package Module::CPANTS::Kwalitee::NeedsCompiler;
 use warnings;
 use strict;
 
-our $VERSION = '0.97_11';
-$VERSION =~ s/_//; ## no critic
-
 sub order { 200 }
 
 ##################################################################
@@ -22,7 +19,7 @@ sub analyse {
             return;
         }
     }
-    if (defined ref($me->d->{prereq}) and ref($me->d->{prereq}) eq 'ARRAY') {
+    if (defined ref($me->d->{prereq}) and ref($me->d->{prereq} eq 'ARRAY')) {
         for my $m (@{ $me->d->{prereq} }) {
             if ($m->{requires} =~ /^Inline::/
                or $m->{requires} eq 'ExtUtils::CBuilder'
@@ -50,7 +47,7 @@ q{Favourite compiler:
 
 __END__
 
-=encoding UTF-8
+=pod
 
 =head1 NAME
 
@@ -72,7 +69,7 @@ Returns C<200>.
 
 =head3 analyse
 
-Checks for file with F<.c>, F<.h> or F<.xs> extensions.
+Checks for file with .c, .h or .xs extensions.
 Check is the module depends on any of the Inline:: modules or
 on ExtUtils::CBuilder or ExtUtils::ParseXS.
 
@@ -81,11 +78,6 @@ on ExtUtils::CBuilder or ExtUtils::ParseXS.
 How to recognize cases such as http://search.cpan.org/dist/Perl-API/ 
 and http://search.cpan.org/dist/Term-Size-Perl
 that generate the .c files during installation
-
-In addition there are modules that can work without their XS part.
-E.g. Scalar-List-Utils, Net-DNS, Template-Toolkit 
-For our purposes these all should be marked as "need C compiler"
-as they need it for their full functionality and speed.
  
 =head3 kwalitee_indicators
 
@@ -97,11 +89,11 @@ L<Module::CPANTS::Analyse>
 
 =head1 AUTHOR
 
-L<Gábor Szabó|https://metacpan.org/author/szabgab>
+Gabor Szabo <gabor@pti.co.il> http://www.pti.co.il
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright © 2006–2008 L<Gábor Szabó|https://metacpan.org/author/szabgab>
+=head1 COPYRIGHT
 
 You may use and distribute this module according to the same terms
 that Perl is distributed under.
+
+=cut
